#!/bin/bash
#
# author           : George Vlahavas (vlahavas~AT~gmail~DOT~com, gapan@zenwalk forums)
# project web page : http://x.mame.net/
# source           : http://x.mame.net/download/xmame-0.106.tar.bz2

# Tarball name
NAME="xmame"
# Zenwalk package name
PKGNAME="xmess"
# Package version
VERSION="0.106"
# Source code URL
SOURCE="http://x.mame.net/download/xmame-$VERSION.tar.bz2"
# Files that should be placed in /usr/doc/package-version/
DOCS="README todo doc/multiplayer-readme.txt doc/changes.unix doc/changes.opengl doc/dga2.txt doc/mess/*"

CWD=`pwd`
PKG="$CWD/$NAME-install"
ARCH="i486"
CPU="i686"
BUILD="48.1"

rm -rf $PKG
mkdir -p $PKG

# Create package install directory
mkdir $PKG/install

# Create the slack-desc file
cat > $PKG/install/slack-desc << END
$PKGNAME: xmess is a port of MESS, the Multi Emulator Super System
$PKGNAME:
$PKGNAME: MESS stands for Multi Emulator Super System. It is an emulator for
$PKGNAME: the hardware of many different games consules (e.g. Sega, NES,
$PKGNAME: SNES, etc.) as well as many different old games-oriented home
$PKGNAME: computers (e.g. C64, C128, ZX80, etc.)
$PKGNAME:
$PKGNAME:
$PKGNAME:
$PKGNAME:
$PKGNAME:
END

# Check to see if source is present. If it's not, download it
rm -rf $NAME-$VERSION
if [ -f $NAME-$VERSION.tar.bz2 ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $SOURCE
fi

# Unpack source
tar xvjf $NAME-$VERSION.tar.bz2

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# 'heavy' computer: 6 build-jobs at once
#
#numjobs='-j6'
#
# 'light' computer: 2 build-jobs at once
#
numjobs='-j2'

# Copy Docs
mkdir -p $PKG/usr/doc/$PKGNAME-$VERSION
cd $CWD/$NAME-$VERSION
cp -a $DOCS $PKG/usr/doc/$PKGNAME-$VERSION

# Patch the makefile and make
cd $CWD/$NAME-$VERSION
sed -i -e 's,TARGET = mame,# TARGET = mame,' Makefile
sed -i -e 's,# TARGET = mess,TARGET = mess,' Makefile
sed -i -e 's,CFLAGS = -O2,CFLAGS = -O2 -march=i486 -mtune=i686,' Makefile
sed -i -e 's,INSTALL_GROUP =        bin,INSTALL_GROUP = root,' Makefile
sed -i -e 's,PREFIX = /usr/local,PREFIX = /usr,' Makefile
sed -i -e 's,BINDIR = ,BINDIR = $(DESTDIR),' Makefile
sed -i -e 's,MANDIR = ,MANDIR = $(DESTDIR),' Makefile
sed -i -e 's,# JOY_STANDARD = 1,JOY_STANDARD = 1,' Makefile
sed -i -e 's,# JOY_SDL = 1,JOY_SDL = 1,' Makefile
sed -i -e 's,# SOUND_ALSA = 1,SOUND_ALSA = 1,' Makefile
sed -i -e 's,# SOUND_SDL = 1,SOUND_SDL = 1,' Makefile
sed -i -e 's,# X11_OPENGL = 1,X11_OPENGL = 1,' Makefile
sed -i -e 's,# XINPUT_DEVICES = 1,XINPUT_DEVICES = 1,' Makefile
sed -i -e 's,# X11_XINERAMA = 1,X11_XINERAMA = 1,' Makefile
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"
make $numjobs

# Install on temporary directory
make install DESTDIR=$PKG

# Create the shared directories for roms etc
mkdir -p $PKG/usr/share/xmess/roms
# Copy over the xmamerc file
cp -a $CWD/$NAME-$VERSION/doc/xmessrc.dist $PKG/usr/share/xmess/xmessrc
sed -i -e 's,/local,,' $PKG/usr/share/xmess/xmessrc
# Copy controller conf files
cp -a $CWD/$NAME-$VERSION/ctrlr $PKG/usr/share/xmess
# Make a symlink for the executable
cd $PKG/usr/bin
ln -sf xmess.x11 xmess

# Strip binaries
cd $PKG
find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

# Compress the man page(s)
find $PKG/usr/man -type f -exec gzip -9 {} \;

# Add the build-file in the package
mkdir -p $PKG/usr/src/$PKGNAME-$VERSION
cp "$CWD/build-$PKGNAME.sh" "$PKG/usr/src/$PKGNAME-$VERSION/build-$PKGNAME.sh"
chmod a+x "$PKG/usr/src/$PKGNAME-$VERSION/build-$PKGNAME.sh"

# Make sure ownerships and permissions are sane
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# Make the package
makepkg -l y -c n $CWD/$PKGNAME-$VERSION-$ARCH-$BUILD.tgz

# Calculate md5sum
cd $CWD/
md5sum $PKGNAME-$VERSION-$ARCH-$BUILD.tgz > $PKGNAME-$VERSION-$ARCH-$BUILD.md5

# Remove source-code and temporary install directories
# since they are not needed anymore
rm -rf $CWD/$NAME-$VERSION
rm -rf $PKG
